@@ -1,6 +1,7 @@
 context("works with web APIs despite network lag")
 
 test_that("requests are received no faster than the allowed rate", {
+    skip_on_cran()
 
     # a function that contains a variable "lag" to
     # represent network lag
@@ -48,6 +49,5 @@ test_that("requests are received no faster than the allowed rate", {
     # now we have a request with a long lag followed immediately
     # by a request with no lag
     responses <- c(probe(1), probe(0))
-    if (!all(responses))
-        fail("limited function broke limits in presence of network lag")
+    expect_true(all(responses))
 })
